For deploying the MicroPython firmware to the SAMD module, follow
the procedure:

-  Push the reset button twice or call machine.bootloader(). A drive
   icon should appear representing a virtual drive.

-  Copy the .uf2 file with the required firmware to that drive.

As soon as the drive disappears, the firmware is loaded and started.

